{"cells": [{"cell_type": "markdown", "id": "591bbd8d", "metadata": {}, "source": ["# Homolytic Cleavage of the C-F Bond\n", "\n", "In this exercise, you will investigate the influence of correlation on\n", "the BDE in a radical process by comparing Hartree-Fock to MPn results.\n", "Consider the reaction enthalpy of the homolytic cleavage of the H$_3$C-F\n", "bond in monofluoro methane: \n", "\n", "$$\n", "\\begin{aligned}\n", "CH_3F \\quad \\rightarrow \\quad H_3C\\cdot \\quad + \\quad F\\cdot\\end{aligned}\n", "$$\n", "\n", "\n", "As in the exercise on hydrogen dissociation, you may calculate the bond\n", "dissociation energy as the difference of the energy of the fragments:\n", "\n", "\n", "$$\n", "\\begin{aligned}\n", "E^{BDE} =  E^{H_3C\\cdot} + E^{F\\cdot} - E^{CH_3F}.\\end{aligned}\n", "$$\n", "\n", "Experimentally, $E^{BDE}$ for this process was determined to be 109.2 kcal mol$^{-1}$ ([*J. Phys. Chem. A*, **2000**, 104, *436*](https://pubs.acs.org/doi/10.1021/jp002317r))."]}, {"cell_type": "markdown", "id": "207f10f6", "metadata": {}, "source": ["Bond dissociation energies of large systems often require the use of\n", "large basis sets of triple-$\\zeta$ quality; you may either use Pople's\n", "6-311+G\\* basis, or the larger aug-cc-pVTZ by Dunning and coworkers (the\n", "choice is up to you; either will take comparably long). As Post-HF\n", "methods require orbitals that diagonalise the Fock operator (*i.e.* the\n", "Hartree-Fock orbitals), the HF orbitals will need to be calculated at\n", "the start of every run.\n", "\n", "The Post-HF treatment itself may take some considerable time. It is\n", "therefore not advisable to run electronic structure calculations with\n", "computationally expensive methods starting from a random guess for the\n", "geometry (since this guess may be considerably off the equilibrium). It\n", "is usually more effective to pre-optimise the geometry at the Hartree-Fock level, and only then carry out the more elaborate calculations on the basis of the converged Hartree-Fock result.\n", "\n", "In Psi4 this is easy as the geometry is automatically updated when calling `psi4.optimize()`.  In other electronic structure programs often checkpoint files are written which contain intermediate states of the geometry and/or wavefunction. "]}, {"cell_type": "markdown", "id": "5aaf22f1", "metadata": {}, "source": ["For MP3 and MP4, one often expects the geometry not to change too much\n", "anymore, and a reasonable estimate for the energy may already be given\n", "by a single-point calculation on the optimised MP2 geometry.\n", "\n", "In general, it is sometimes necessary to optimise the geometry at a\n", "lower Post-Hartree-Fock level, followed by a higher level single point\n", "calculation. This is due to a lack of available analytical gradients for\n", "certain higher order methods (such as MP4), which causes the\n", "computational time for a geometry optimisation to become exorbitantly\n", "high."]}, {"cell_type": "markdown", "id": "6fbb5a5f", "metadata": {}, "source": [":::{admonition} Exercise 2\n", ":class: exercise \n", "Perform the calculations below and complete the following table.\n", "\n", " |Method:         |   HF   | MP2  |  MP3  |          Exp.          |\n", " | :--------------| :----: | :--- | :---- |  :-------------------- |\n", " |$E^{F\\cdot}$    |        |      |       |        n/a             |\n", " |$E^{H_3C\\cdot}$ |        |      |       |        n/a             |\n", " |$E^{CH_3F}$     |        |      |       |        n/a             |\n", " |$E^{BDE}$       |        |      |       |  109.2 kcal mol$^{-1}$ |\n", ":::"]}, {"cell_type": "code", "execution_count": 1, "id": "b59cce45", "metadata": {}, "outputs": [], "source": ["import psi4\n", "import py3Dmol\n", "import pandas as pd\n", "import matplotlib.pyplot as plt\n", "\n", "import sys\n", "sys.path.append(\"..\")\n", "from helpers import *"]}, {"cell_type": "code", "execution_count": 2, "id": "71c0d150", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["  Threads set to 2 by Python driver.\n", "\n", "  Memory set to   1.863 GiB by Python driver.\n"]}, {"data": {"text/plain": ["2000000000"]}, "execution_count": 2, "metadata": {}, "output_type": "execute_result"}], "source": ["psi4.set_num_threads(2)\n", "psi4.set_memory('2 GB')"]}, {"cell_type": "code", "execution_count": 3, "id": "7b0daeb9-ee78-42ca-aaee-7f8a8b27aa57", "metadata": {}, "outputs": [], "source": ["# setup dictionary to store results in\n", "energies = {'hf':{\n", "                 'ch3f':None,\n", "                 'ch3':None,\n", "                 'f':None\n", "                },\n", "            'mp2':{\n", "                 'ch3f':None,\n", "                 'ch3':None,\n", "                 'f':None\n", "                },\n", "            'mp3':{\n", "                 'ch3f':None,\n", "                 'ch3':None,\n", "                 'f':None\n", "                },\n", "           }"]}, {"cell_type": "markdown", "id": "83df15c2-e978-48a2-9761-0490043f79fe", "metadata": {}, "source": ["### CH3F molecule"]}, {"cell_type": "code", "execution_count": 4, "id": "77eeed03", "metadata": {}, "outputs": [], "source": ["ch3f = psi4.geometry(\"\"\"\n", "0 1\n", "symmetry c1\n", "    F           -0.642381967195     0.000000095800    -0.000000000108\n", "    C            0.742340417015    -0.000000119001     0.000000000132\n", "    H            1.090184715481    -1.027287458657     0.000000000131\n", "    H            1.090184841794     0.513643534810    -0.889656896780\n", "    H            1.090184842203     0.513643534859     0.889656897127\n", "\"\"\")"]}, {"cell_type": "code", "execution_count": 5, "id": "7be07fc8", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_16692155728389642\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_16692155728389642\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_16692155728389642 = null;\nvar warn = document.getElementById(\"3dmolwarning_16692155728389642\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_16692155728389642 = $3Dmol.createViewer($(\"#3dmolviewer_16692155728389642\"),{backgroundColor:\"white\"});\nviewer_16692155728389642.zoomTo();\n\tviewer_16692155728389642.addModel(\"5\\n\\n F   -0.642381967195    0.000000095800   -0.000000000108\\n C    0.742340417015   -0.000000119001    0.000000000132\\n H    1.090184715481   -1.027287458657    0.000000000131\\n H    1.090184841794    0.513643534810   -0.889656896780\\n H    1.090184842203    0.513643534859    0.889656897127\\n\",\"xyz\");\n\tviewer_16692155728389642.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16692155728389642.zoomTo();\nviewer_16692155728389642.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_16692155728389642\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_16692155728389642\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_16692155728389642 = null;\n", "var warn = document.getElementById(\"3dmolwarning_16692155728389642\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_16692155728389642 = $3Dmol.createViewer($(\"#3dmolviewer_16692155728389642\"),{backgroundColor:\"white\"});\n", "viewer_16692155728389642.zoomTo();\n", "\tviewer_16692155728389642.addModel(\"5\\n\\n F   -0.642381967195    0.000000095800   -0.000000000108\\n C    0.742340417015   -0.000000119001    0.000000000132\\n H    1.090184715481   -1.027287458657    0.000000000131\\n H    1.090184841794    0.513643534810   -0.889656896780\\n H    1.090184842203    0.513643534859    0.889656897127\\n\",\"xyz\");\n", "\tviewer_16692155728389642.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16692155728389642.zoomTo();\n", "viewer_16692155728389642.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(ch3f)"]}, {"cell_type": "code", "execution_count": 6, "id": "0a4b3ad5", "metadata": {}, "outputs": [], "source": ["psi4.core.set_output_file('ch3f.log', False)"]}, {"cell_type": "code", "execution_count": 7, "id": "cc55ab0d", "metadata": {"scrolled": true}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({'reference':'uhf'}) \n", "energies['hf']['ch3f'] = psi4.optimize('hf/aug-cc-pvdz')"]}, {"cell_type": "code", "execution_count": 8, "id": "53bd3d15", "metadata": {"scrolled": true}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({\"reference\" :\"uhf\",\"mp2_type\":\"conv\"})\n", "energies['mp2']['ch3f']  = psi4.optimize('mp2/aug-cc-pvdz')"]}, {"cell_type": "markdown", "id": "2102343c-0264-46e4-9d42-09aaffd3214f", "metadata": {}, "source": [":::{admonition} Exercise 3\n", ":class: exercise \n", "Why is it a reasonable choice to use Hartree-Fock geometries and\n", "    wavefunctions as a starting point for optimisations at the\n", "    Post-Hartree-Fock level? What is the advantage and how is this\n", "    approach justified?\n", ":::"]}, {"cell_type": "code", "execution_count": 9, "id": "2b2d8305", "metadata": {}, "outputs": [], "source": ["energies['mp3']['ch3f'] = psi4.energy('mp3/aug-cc-pvdz')"]}, {"cell_type": "markdown", "id": "6cbb5076-ebdc-422d-a0cc-5d6f1930ee75", "metadata": {}, "source": [":::{admonition} Exercise 4\n", ":class: exercise \n", "Why do you think it is reasonable to choose not to carry out a geometry optimisation for mp3?\n", ":::"]}, {"cell_type": "code", "execution_count": 32, "id": "6da7293e-66a8-41ae-85fe-5bd859677f8c", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_166921579256644\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_166921579256644\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_166921579256644 = null;\nvar warn = document.getElementById(\"3dmolwarning_166921579256644\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_166921579256644 = $3Dmol.createViewer($(\"#3dmolviewer_166921579256644\"),{backgroundColor:\"white\"});\nviewer_166921579256644.zoomTo();\n\tviewer_166921579256644.addModel(\"5\\n\\n F    0.652123810953   -0.000000071765    0.000000000364\\n C   -0.755115976279    0.000000082967   -0.000000000539\\n H   -1.100693373745    1.041608449843    0.000000000081\\n H   -1.100693549039   -0.520804042642   -0.902059273546\\n H   -1.100693548261   -0.520804042244    0.902059273020\\n\",\"xyz\");\n\tviewer_166921579256644.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_166921579256644.zoomTo();\nviewer_166921579256644.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_166921579256644\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_166921579256644\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_166921579256644 = null;\n", "var warn = document.getElementById(\"3dmolwarning_166921579256644\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_166921579256644 = $3Dmol.createViewer($(\"#3dmolviewer_166921579256644\"),{backgroundColor:\"white\"});\n", "viewer_166921579256644.zoomTo();\n", "\tviewer_166921579256644.addModel(\"5\\n\\n F    0.652123810953   -0.000000071765    0.000000000364\\n C   -0.755115976279    0.000000082967   -0.000000000539\\n H   -1.100693373745    1.041608449843    0.000000000081\\n H   -1.100693549039   -0.520804042642   -0.902059273546\\n H   -1.100693548261   -0.520804042244    0.902059273020\\n\",\"xyz\");\n", "\tviewer_166921579256644.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_166921579256644.zoomTo();\n", "viewer_166921579256644.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(ch3f)"]}, {"cell_type": "markdown", "id": "a211e2c0", "metadata": {}, "source": ["### CH3&middot; radical"]}, {"cell_type": "code", "execution_count": 11, "id": "6c3ca485", "metadata": {}, "outputs": [], "source": ["psi4.core.clean_options()\n", "psi4.core.clean()"]}, {"cell_type": "code", "execution_count": 34, "id": "c28a28f9", "metadata": {}, "outputs": [], "source": ["ch3_radical = psi4.geometry(\"\"\"\n", "0 2\n", "symmetry c1\n", "C        0.749   0.000   0.000\n", "H        1.112   0.000   1.028\n", "H        1.112  -0.890  -0.514\n", "H        1.112   0.890  -0.514\n", "\"\"\")"]}, {"cell_type": "code", "execution_count": 35, "id": "731ab64e", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_16692158019781544\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_16692158019781544\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_16692158019781544 = null;\nvar warn = document.getElementById(\"3dmolwarning_16692158019781544\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_16692158019781544 = $3Dmol.createViewer($(\"#3dmolviewer_16692158019781544\"),{backgroundColor:\"white\"});\nviewer_16692158019781544.zoomTo();\n\tviewer_16692158019781544.addModel(\"4\\n\\n C    0.073053767723   -0.000000000000   -0.000000000000\\n H   -0.289946232277    1.028000000000   -0.000000000000\\n H   -0.289946232277   -0.514000000000   -0.890000000000\\n H   -0.289946232277   -0.514000000000    0.890000000000\\n\",\"xyz\");\n\tviewer_16692158019781544.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16692158019781544.zoomTo();\nviewer_16692158019781544.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_16692158019781544\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_16692158019781544\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_16692158019781544 = null;\n", "var warn = document.getElementById(\"3dmolwarning_16692158019781544\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_16692158019781544 = $3Dmol.createViewer($(\"#3dmolviewer_16692158019781544\"),{backgroundColor:\"white\"});\n", "viewer_16692158019781544.zoomTo();\n", "\tviewer_16692158019781544.addModel(\"4\\n\\n C    0.073053767723   -0.000000000000   -0.000000000000\\n H   -0.289946232277    1.028000000000   -0.000000000000\\n H   -0.289946232277   -0.514000000000   -0.890000000000\\n H   -0.289946232277   -0.514000000000    0.890000000000\\n\",\"xyz\");\n", "\tviewer_16692158019781544.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16692158019781544.zoomTo();\n", "viewer_16692158019781544.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(ch3_radical)"]}, {"cell_type": "code", "execution_count": 14, "id": "a22debe7", "metadata": {}, "outputs": [], "source": ["psi4.core.set_output_file(f'ch3_radical.log', False)"]}, {"cell_type": "code", "execution_count": 15, "id": "421be9fa", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({\"reference\" :\"uhf\",\"guess\":\"gwh\", \"opt_coordinates\": \"both\"})\n", "energies['hf']['ch3'] = psi4.optimize('hf/aug-cc-pvdz', molecule=ch3_radical)"]}, {"cell_type": "code", "execution_count": 16, "id": "150696a8", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({\"reference\" :\"uhf\",\"guess\":\"gwh\", \"mp2_type\":\"conv\", \"opt_coordinates\": \"both\"})\n", "energies['mp2']['ch3'] = psi4.optimize('mp2/aug-cc-pvdz', molecule=ch3_radical)"]}, {"cell_type": "code", "execution_count": 17, "id": "daf04fb4-bfb4-4471-b689-5aca8e4857bb", "metadata": {}, "outputs": [], "source": ["energies['mp3']['ch3'] = psi4.energy('mp3/aug-cc-pvdz', molecule=ch3_radical)"]}, {"cell_type": "code", "execution_count": 33, "id": "9fab3ae5", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_1669215797514664\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_1669215797514664\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_1669215797514664 = null;\nvar warn = document.getElementById(\"3dmolwarning_1669215797514664\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_1669215797514664 = $3Dmol.createViewer($(\"#3dmolviewer_1669215797514664\"),{backgroundColor:\"white\"});\nviewer_1669215797514664.zoomTo();\n\tviewer_1669215797514664.addModel(\"4\\n\\n C    0.000004358475   -0.000000133316   -0.000000000003\\n H   -0.000007787374    1.086882376415   -0.000000000116\\n H   -0.000022053527   -0.543440394675   -0.941268452604\\n H   -0.000022054710   -0.543440394367    0.941268452756\\n\",\"xyz\");\n\tviewer_1669215797514664.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_1669215797514664.zoomTo();\nviewer_1669215797514664.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_1669215797514664\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_1669215797514664\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_1669215797514664 = null;\n", "var warn = document.getElementById(\"3dmolwarning_1669215797514664\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_1669215797514664 = $3Dmol.createViewer($(\"#3dmolviewer_1669215797514664\"),{backgroundColor:\"white\"});\n", "viewer_1669215797514664.zoomTo();\n", "\tviewer_1669215797514664.addModel(\"4\\n\\n C    0.000004358475   -0.000000133316   -0.000000000003\\n H   -0.000007787374    1.086882376415   -0.000000000116\\n H   -0.000022053527   -0.543440394675   -0.941268452604\\n H   -0.000022054710   -0.543440394367    0.941268452756\\n\",\"xyz\");\n", "\tviewer_1669215797514664.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_1669215797514664.zoomTo();\n", "viewer_1669215797514664.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(ch3_radical)"]}, {"cell_type": "markdown", "id": "560b9a81", "metadata": {}, "source": ["### F &middot; radical"]}, {"cell_type": "code", "execution_count": 19, "id": "70a276a5-0729-43e9-a770-88a6f5749646", "metadata": {}, "outputs": [], "source": ["psi4.core.clean_options()\n", "psi4.core.clean()"]}, {"cell_type": "code", "execution_count": 20, "id": "680b2906", "metadata": {}, "outputs": [], "source": ["f_radical = psi4.geometry(\"\"\"\n", "0 2\n", "symmetry c1\n", "F       -0.650  -0.000   0.000\n", "\"\"\")"]}, {"cell_type": "code", "execution_count": 36, "id": "78335927-4bd6-41b9-8df2-8a8a1937d902", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_16692158083678055\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_16692158083678055\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_16692158083678055 = null;\nvar warn = document.getElementById(\"3dmolwarning_16692158083678055\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_16692158083678055 = $3Dmol.createViewer($(\"#3dmolviewer_16692158083678055\"),{backgroundColor:\"white\"});\nviewer_16692158083678055.zoomTo();\n\tviewer_16692158083678055.addModel(\"1\\n\\n F   -0.000000000000    0.000000000000    0.000000000000\\n\",\"xyz\");\n\tviewer_16692158083678055.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16692158083678055.zoomTo();\nviewer_16692158083678055.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_16692158083678055\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_16692158083678055\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_16692158083678055 = null;\n", "var warn = document.getElementById(\"3dmolwarning_16692158083678055\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_16692158083678055 = $3Dmol.createViewer($(\"#3dmolviewer_16692158083678055\"),{backgroundColor:\"white\"});\n", "viewer_16692158083678055.zoomTo();\n", "\tviewer_16692158083678055.addModel(\"1\\n\\n F   -0.000000000000    0.000000000000    0.000000000000\\n\",\"xyz\");\n", "\tviewer_16692158083678055.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16692158083678055.zoomTo();\n", "viewer_16692158083678055.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(f_radical)"]}, {"cell_type": "code", "execution_count": 22, "id": "e7bc32c8-02f7-4d4f-88ae-5bd6ff840419", "metadata": {}, "outputs": [], "source": ["psi4.core.set_output_file(f'f_radical.log', False)"]}, {"cell_type": "code", "execution_count": 23, "id": "4e8f4d9b", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({\"reference\" :\"uhf\", \"guess\":\"gwh\", \"opt_coordinates\": \"both\"})\n", "energies['hf']['f'] = psi4.optimize('hf/aug-cc-pvdz')"]}, {"cell_type": "code", "execution_count": 24, "id": "1d71eb30", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["Optimizer: Optimization complete!\n"]}], "source": ["psi4.set_options({\"reference\" :\"uhf\",\"guess\":\"gwh\", \"mp2_type\":\"conv\", \"opt_coordinates\": \"both\"})\n", "energies['mp2']['f'] = psi4.optimize('mp2/aug-cc-pvdz')"]}, {"cell_type": "code", "execution_count": 25, "id": "d85841a9", "metadata": {}, "outputs": [], "source": ["energies['mp3']['f'] = psi4.energy('mp3/aug-cc-pvdz')"]}, {"cell_type": "markdown", "id": "acdd6616-7342-4195-9597-f91d8963ac48", "metadata": {}, "source": ["### BDE\n", "\n", "Now that we performed all the calculations required, it is finally possible to compute the BDE for the reaction."]}, {"cell_type": "code", "execution_count": 26, "id": "5f0d341d", "metadata": {}, "outputs": [], "source": ["# calculate the BDE energies here and convert them to kcal/mol \n", "# You can use psi4.constants.hartree2kcalmol for the unit conversion\n", "\n", "energies['hf']['bde'] = None # \n", "energies['mp2']['bde'] = None # \n", "energies['mp3']['bde'] = None # \n"]}, {"cell_type": "code", "execution_count": null, "id": "89433bd7", "metadata": {}, "outputs": [], "source": ["pd.DataFrame.from_dict(energies)"]}, {"cell_type": "markdown", "id": "5946a1d5-b266-4560-a3ef-b9614567c53e", "metadata": {}, "source": [":::{admonition} Exercise 5\n", ":class: exercise \n", "Is the homolytic cleavage of the H$_3$C-F bond likely, based on the\n", "    BDE that you calculated? (Think of radical processes in general.)\n", ":::"]}, {"cell_type": "markdown", "id": "41a47e34-19da-4f89-9b6a-30a8755fbfb4", "metadata": {}, "source": [":::{admonition} Exercise 6\n", ":class: exercise \n", "What is the trend in energies when moving from HF over MP2 to MP3 for your calculations? Does this series converge? Do you expect the same trend for higher order MPn methods? Why? \n", "\n", "*Hint*: You can check the convergence for MP2 and MP3 by running the code cell below.\n", ":::"]}, {"cell_type": "code", "execution_count": null, "id": "2cac66dc-242c-478d-b74f-81a9d07aaa84", "metadata": {}, "outputs": [], "source": ["fig, (ax1,ax2,ax3) = plt.subplots(3,1,constrained_layout = True)\n", "\n", "ax1.plot([1,2,3],[energies['hf']['ch3f'],energies['mp2']['ch3f'],energies['mp3']['ch3f']],'o-')\n", "ax1.set_xlabel('Method')\n", "ax1.set_ylabel('Energy (kcal/mol)')\n", "ax1.set_xticks([1, 2, 3])\n", "ax1.set_xticklabels(['HF', 'MP2', 'MP3'])\n", "\n", "ax2.plot([1,2,3],[energies['hf']['ch3'],energies['mp2']['ch3'],energies['mp3']['ch3']],'o-')\n", "ax2.set_xlabel('Method')\n", "ax2.set_ylabel('Energy (kcal/mol)')\n", "ax2.set_xticks([1, 2, 3])\n", "ax2.set_xticklabels(['HF', 'MP2', 'MP3'])\n", "\n", "ax3.plot([1,2,3],[energies['hf']['f'],energies['mp2']['f'],energies['mp3']['f']],'o-')\n", "ax3.set_xlabel('Method')\n", "ax3.set_ylabel('Energy (kcal/mol)')\n", "ax3.set_xticks([1, 2, 3])\n", "ax3.set_xticklabels(['HF', 'MP2', 'MP3'])\n", "\n", "#plt.gcf().set_dpi(300)\n", "plt.show()"]}, {"cell_type": "markdown", "id": "a8d01e54-e8ee-46ef-96a6-a0b32dfb0824", "metadata": {}, "source": [":::{admonition} Exercise 7\n", ":class: exercise \n", "Comment on the accuracy of the HF approach for this system. If the\n", "    difference between HF and MPn is large, how is the use of MPn still\n", "    justified? (*Hint*: Think in terms of the scale of the absolute energy\n", "    of the system, rather than the reaction.)\n", ":::"]}], "metadata": {"celltoolbar": "Tags", "kernelspec": {"display_name": "Computational Chemistry", "language": "python", "name": "compchem"}, "language_info": {"codemirror_mode": {"name": "ipython", "version": 3}, "file_extension": ".py", "mimetype": "text/x-python", "name": "python", "nbconvert_exporter": "python", "pygments_lexer": "ipython3", "version": "3.8.12"}, "unianalytics_cell_mapping": [["591bbd8d", "591bbd8d"], ["207f10f6", "207f10f6"], ["5aaf22f1", "5aaf22f1"], ["6fbb5a5f", "6fbb5a5f"], ["41fb0a3f", "41fb0a3f"], ["b59cce45", "b59cce45"], ["71c0d150", "71c0d150"], ["7b0daeb9-ee78-42ca-aaee-7f8a8b27aa57", "7b0daeb9-ee78-42ca-aaee-7f8a8b27aa57"], ["83df15c2-e978-48a2-9761-0490043f79fe", "83df15c2-e978-48a2-9761-0490043f79fe"], ["77eeed03", "77eeed03"], ["7be07fc8", "7be07fc8"], ["0a4b3ad5", "0a4b3ad5"], ["cc55ab0d", "cc55ab0d"], ["53bd3d15", "53bd3d15"], ["2102343c-0264-46e4-9d42-09aaffd3214f", "2102343c-0264-46e4-9d42-09aaffd3214f"], ["230eeaab-00b1-4b7c-b227-d53463fd364f", "230eeaab-00b1-4b7c-b227-d53463fd364f"], ["2b2d8305", "2b2d8305"], ["6cbb5076-ebdc-422d-a0cc-5d6f1930ee75", "6cbb5076-ebdc-422d-a0cc-5d6f1930ee75"], ["6aa64ae5-6b33-41f2-aaba-0cbadd6960e8", "6aa64ae5-6b33-41f2-aaba-0cbadd6960e8"], ["6da7293e-66a8-41ae-85fe-5bd859677f8c", "6da7293e-66a8-41ae-85fe-5bd859677f8c"], ["a211e2c0", "a211e2c0"], ["6c3ca485", "6c3ca485"], ["c28a28f9", "c28a28f9"], ["731ab64e", "731ab64e"], ["a22debe7", "a22debe7"], ["421be9fa", "421be9fa"], ["150696a8", "150696a8"], ["daf04fb4-bfb4-4471-b689-5aca8e4857bb", "daf04fb4-bfb4-4471-b689-5aca8e4857bb"], ["9fab3ae5", "9fab3ae5"], ["560b9a81", "560b9a81"], ["70a276a5-0729-43e9-a770-88a6f5749646", "70a276a5-0729-43e9-a770-88a6f5749646"], ["680b2906", "680b2906"], ["78335927-4bd6-41b9-8df2-8a8a1937d902", "78335927-4bd6-41b9-8df2-8a8a1937d902"], ["e7bc32c8-02f7-4d4f-88ae-5bd6ff840419", "e7bc32c8-02f7-4d4f-88ae-5bd6ff840419"], ["4e8f4d9b", "4e8f4d9b"], ["1d71eb30", "1d71eb30"], ["d85841a9", "d85841a9"], ["acdd6616-7342-4195-9597-f91d8963ac48", "acdd6616-7342-4195-9597-f91d8963ac48"], ["5f0d341d", "5f0d341d"], ["2809270e", "2809270e"], ["89433bd7", "89433bd7"], ["8d90a460", "8d90a460"], ["5946a1d5-b266-4560-a3ef-b9614567c53e", "5946a1d5-b266-4560-a3ef-b9614567c53e"], ["25328183-31d3-4fe2-9e07-b0d60266b5ac", "25328183-31d3-4fe2-9e07-b0d60266b5ac"], ["41a47e34-19da-4f89-9b6a-30a8755fbfb4", "41a47e34-19da-4f89-9b6a-30a8755fbfb4"], ["2cac66dc-242c-478d-b74f-81a9d07aaa84", "2cac66dc-242c-478d-b74f-81a9d07aaa84"], ["ed421a05-e888-42ba-94be-e2c0885325aa", "ed421a05-e888-42ba-94be-e2c0885325aa"], ["c4107967-8985-4673-823c-3f199d936cdd", "c4107967-8985-4673-823c-3f199d936cdd"], ["a8d01e54-e8ee-46ef-96a6-a0b32dfb0824", "a8d01e54-e8ee-46ef-96a6-a0b32dfb0824"], ["59757e51-3ed7-4849-bc4d-ed330d67ccb3", "59757e51-3ed7-4849-bc4d-ed330d67ccb3"]], "unianalytics_notebook_id": "1d7e91ec-c220-4322-a01a-2c777163d72f"}, "nbformat": 4, "nbformat_minor": 5}